@@ -32,6 +32,7 @@ class Service(object):
     name = None
 
     def start(self):
+        log.debug("Starting %s", self.name)
         util.start_thread(self._run, name=self.name)
 
     def stop(self):
@@ -47,7 +48,7 @@ class Service(object):
         return self._server.server_address
 
     def _run(self):
-        log.debug("Starting %s", self.name)
+        log.debug("%s started", self.name)
         self._server.serve_forever(
             poll_interval=self._config.daemon.poll_interval)
         log.debug("%s terminated normally", self.name)
@@ -68,6 +69,7 @@ class RemoteService(Service):
         port = config.remote.port
         if not 0 <= port < 0xFFFF:
             raise errors.InvalidConfig("remote.port", port)
+        log.debug("Creating %s on port %d", self.name, port)
         self._server = http.Server((config.remote.host, port), http.Connection)
         # TODO: Make clock configurable, disabled by default.
         self._server.clock_class = util.Clock
@@ -116,6 +118,7 @@ class LocalService(Service):
 
     def __init__(self, config, auth):
         self._config = config
+        log.debug("Creating %s on socket %r", self.name, config.local.socket)
         self._server = uhttp.Server(config.local.socket, uhttp.Connection)
         # TODO: Make clock configurable, disabled by default.
         self._server.clock_class = util.Clock
@@ -143,7 +146,7 @@ class ControlService(Service):
         transport = self._config.control.transport.lower()
         if transport == "tcp":
             port = config.control.port
-            log.debug("Starting control service on port %r", port)
+            log.debug("Creating %s on port %r", self.name, port)
             if not 0 <= port < 0xFFFF:
                 raise errors.InvalidConfig("control.port", port)
             self._server = http.Server(("localhost", port), http.Connection)
@@ -151,7 +154,7 @@ class ControlService(Service):
                 config.control.port = self.port
         elif transport == "unix":
             socket = config.control.socket
-            log.debug("Starting control service on socket %r", socket)
+            log.debug("Creating %s on socket %r", self.name, socket)
             self._server = uhttp.Server(socket, uhttp.Connection)
             if socket == "":
                 config.control.socket = self.address
